(ns wanijo.view
  (:require [hiccup.page :refer [html5
                                 include-css]]
            [clojure.spec.alpha :as spec]))

(defn btnlink
  ([target caption]
   (btnlink target caption ""))
  ([target caption class]
   [:a {:href target}
    [:button {:class class}
     caption]]))

(defn layout!
  [& {:keys [content title session]
      :or {content []
           title nil
           session {}}}]
  (println session)
  (let [ident (:ident session)
        authed? (some? ident)]
    (html5
     [:head
      [:meta {:charset "utf-8"}]
      [:meta {:name "viewport"
              :content "width=device-width,initial-scale=1,shrink-to-fit=no"}]
      [:title (str "wan ijo" (when title (str " - " title)))]
      (include-css "/css/app.css")]
     [:body
      [:section.grid
       [:header
        [:h1.app-title "wan ijo"
         (when authed?
           [:small.app-title__hello
            (str "O, " ident)])]
        (when authed?
          [:section.header-content
           (btnlink "/schema" "Jaki ijo" "header-content__link")
           (btnlink "/logout" "Lape" "header-content__link")])]
       [:nav (when authed? "nav")]
       (vec (concat [:main] content))
       [:aside (when authed? "aside")]
       [:footer
        [:small "Ilo pali e ijo"]]]])))

(defn flash-error [content]
  [:section.flash--error
   [:h2.flash__heading--error "Pakala"]
   content])

(defn spec-to-errmsg [spec-key req]
  (when-let [spec-data (and (not-empty (:params req))
                            (spec/explain-data spec-key (:params req)))]
    (flash-error
     (->> (:clojure.spec.alpha/problems spec-data)
          (map
           (fn [prob]
             [:p
              "Field \""
              [:span.flash__field (first (:path prob))]
              "\" must comply to "
              [:span.flash__pred (:pred prob)]]))))))
